@@ -68,6 +68,8 @@ OC.L10N.register(
     "Error while changing permissions" : "حصل خطأ عند عملية إعادة تعيين التصريح بالتوصل",
     "Shared with you and the group {group} by {owner}" : "شورك معك ومع المجموعة {group} من قبل {owner}",
     "Shared with you by {owner}" : "شورك معك من قبل {owner}",
+    "Share with users or groups …" : "شارِك مع مستخدمين أو مجموعات",
+    "Share with users, groups or remote users …" : "شارِك مع مستخدمين أو مجموعات أو مستخدمين عن بُعد",
     "Share" : "شارك",
     "Share link" : "شارك الرابط",
     "Link" : "الرابط",
